@@ -29,17 +29,15 @@
 
 #include "torrent.h"
 
+#include <limits>
+
 #include <QHash>
 
 #include "infohash.h"
 
 namespace BitTorrent
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
     std::size_t qHash(const TorrentState key, const std::size_t seed)
-#else
-    uint qHash(const TorrentState key, const uint seed)
-#endif
     {
         return ::qHash(static_cast<std::underlying_type_t<TorrentState>>(key), seed);
     }
@@ -55,18 +53,16 @@ namespace BitTorrent
     const int Torrent::USE_GLOBAL_INACTIVE_SEEDING_TIME = -2;
     const int Torrent::NO_INACTIVE_SEEDING_TIME_LIMIT = -1;
 
-    const qreal Torrent::MAX_RATIO = 9999;
-    const int Torrent::MAX_SEEDING_TIME = 525600;
-    const int Torrent::MAX_INACTIVE_SEEDING_TIME = 525600;
+    const qreal Torrent::MAX_RATIO = std::numeric_limits<qreal>::infinity();
 
     TorrentID Torrent::id() const
     {
         return infoHash().toTorrentID();
     }
 
-    bool Torrent::isResumed() const
+    bool Torrent::isRunning() const
     {
-        return !isPaused();
+        return !isStopped();
     }
 
     qlonglong Torrent::remainingSize() const
