@@ -1,6 +1,6 @@
 /*
  * Bittorrent Client using Qt and libtorrent.
- * Copyright (C) 2021  Vladimir Golovnev <glassez@yandex.ru>
+ * Copyright (C) 2021-2023  Vladimir Golovnev <glassez@yandex.ru>
  * Copyright (C) 2010  Christian Kandeler, Christophe Dumez <chris@qbittorrent.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@
 
 #include <chrono>
 
-#include <QtGlobal>
+#include <QtAssert>
 #include <QDir>
 #include <QDirIterator>
 #include <QFile>
@@ -44,11 +44,9 @@
 #include <QVariant>
 
 #include "base/algorithm.h"
-#include "base/bittorrent/magneturi.h"
 #include "base/bittorrent/torrentcontentlayout.h"
 #include "base/bittorrent/session.h"
 #include "base/bittorrent/torrent.h"
-#include "base/bittorrent/torrentinfo.h"
 #include "base/exceptions.h"
 #include "base/global.h"
 #include "base/logger.h"
@@ -99,8 +97,7 @@ public slots:
     void removeWatchedFolder(const Path &path);
 
 signals:
-    void magnetFound(const BitTorrent::MagnetUri &magnetURI, const BitTorrent::AddTorrentParams &addTorrentParams);
-    void torrentFound(const BitTorrent::TorrentInfo &torrentInfo, const BitTorrent::AddTorrentParams &addTorrentParams);
+    void torrentFound(const BitTorrent::TorrentDescriptor &torrentDescr, const BitTorrent::AddTorrentParams &addTorrentParams);
 
 private:
     void onTimeout();
@@ -145,11 +142,11 @@ TorrentFilesWatcher::TorrentFilesWatcher(QObject *parent)
     , m_ioThread {new QThread}
     , m_asyncWorker {new TorrentFilesWatcher::Worker(new QFileSystemWatcher(this))}
 {
-    connect(m_asyncWorker, &TorrentFilesWatcher::Worker::magnetFound, this, &TorrentFilesWatcher::onMagnetFound);
     connect(m_asyncWorker, &TorrentFilesWatcher::Worker::torrentFound, this, &TorrentFilesWatcher::onTorrentFound);
 
     m_asyncWorker->moveToThread(m_ioThread.get());
     connect(m_ioThread.get(), &QThread::finished, m_asyncWorker, &QObject::deleteLater);
+    m_ioThread->setObjectName("TorrentFilesWatcher m_ioThread");
     m_ioThread->start();
 
     load();
@@ -213,7 +210,7 @@ void TorrentFilesWatcher::loadLegacy()
     {
         const Path watchedFolder {it.key()};
         BitTorrent::AddTorrentParams params;
-        if (it.value().type() == QVariant::Int)
+        if (it.value().userType() == QMetaType::Int)
         {
             if (it.value().toInt() == 0)
             {
@@ -309,16 +306,10 @@ void TorrentFilesWatcher::removeWatchedFolder(const Path &path)
     }
 }
 
-void TorrentFilesWatcher::onMagnetFound(const BitTorrent::MagnetUri &magnetURI
-                                         , const BitTorrent::AddTorrentParams &addTorrentParams)
+void TorrentFilesWatcher::onTorrentFound(const BitTorrent::TorrentDescriptor &torrentDescr
+        , const BitTorrent::AddTorrentParams &addTorrentParams)
 {
-    BitTorrent::Session::instance()->addTorrent(magnetURI, addTorrentParams);
-}
-
-void TorrentFilesWatcher::onTorrentFound(const BitTorrent::TorrentInfo &torrentInfo
-                                         , const BitTorrent::AddTorrentParams &addTorrentParams)
-{
-    BitTorrent::Session::instance()->addTorrent(torrentInfo, addTorrentParams);
+    BitTorrent::Session::instance()->addTorrent(torrentDescr, addTorrentParams);
 }
 
 TorrentFilesWatcher::Worker::Worker(QFileSystemWatcher *watcher)
@@ -415,7 +406,10 @@ void TorrentFilesWatcher::Worker::processFolder(const Path &path, const Path &wa
                     while (!file.atEnd())
                     {
                         const auto line = QString::fromLatin1(file.readLine()).trimmed();
-                        emit magnetFound(BitTorrent::MagnetUri(line), addTorrentParams);
+                        if (const auto parseResult = BitTorrent::TorrentDescriptor::parse(line))
+                            emit torrentFound(parseResult.value(), addTorrentParams);
+                        else
+                            LogMsg(tr("Invalid Magnet URI. URI: %1. Reason: %2").arg(line, parseResult.error()), Log::WARNING);
                     }
 
                     file.close();
@@ -423,7 +417,7 @@ void TorrentFilesWatcher::Worker::processFolder(const Path &path, const Path &wa
                 }
                 else
                 {
-                    LogMsg(tr("Magnet file too big. File: %1").arg(file.errorString()));
+                    LogMsg(tr("Magnet file too big. File: %1").arg(file.errorString()), Log::WARNING);
                 }
             }
             else
@@ -433,10 +427,9 @@ void TorrentFilesWatcher::Worker::processFolder(const Path &path, const Path &wa
         }
         else
         {
-            const nonstd::expected<BitTorrent::TorrentInfo, QString> result = BitTorrent::TorrentInfo::loadFromFile(filePath);
-            if (result)
+            if (const auto loadResult = BitTorrent::TorrentDescriptor::loadFromFile(filePath))
             {
-                emit torrentFound(result.value(), addTorrentParams);
+                emit torrentFound(loadResult.value(), addTorrentParams);
                 Utils::Fs::removeFile(filePath);
             }
             else
@@ -451,10 +444,10 @@ void TorrentFilesWatcher::Worker::processFolder(const Path &path, const Path &wa
 
     if (options.recursive)
     {
-        QDirIterator dirIter {path.data(), (QDir::Dirs | QDir::NoDot | QDir::NoDotDot)};
-        while (dirIter.hasNext())
+        QDirIterator iter {path.data(), (QDir::Dirs | QDir::NoDotAndDotDot)};
+        while (iter.hasNext())
         {
-            const Path folderPath {dirIter.next()};
+            const Path folderPath {iter.next()};
             // Skip processing of subdirectory that is explicitly set as watched folder
             if (!m_watchedFolders.contains(folderPath))
                 processFolder(folderPath, watchedFolderPath, options);
@@ -473,8 +466,7 @@ void TorrentFilesWatcher::Worker::processFailedTorrents()
             if (!torrentPath.exists())
                 return true;
 
-            const nonstd::expected<BitTorrent::TorrentInfo, QString> result = BitTorrent::TorrentInfo::loadFromFile(torrentPath);
-            if (result)
+            if (const auto loadResult = BitTorrent::TorrentDescriptor::loadFromFile(torrentPath))
             {
                 BitTorrent::AddTorrentParams addTorrentParams = options.addTorrentParams;
                 if (torrentPath != watchedFolderPath)
@@ -492,7 +484,7 @@ void TorrentFilesWatcher::Worker::processFailedTorrents()
                     }
                 }
 
-                emit torrentFound(result.value(), addTorrentParams);
+                emit torrentFound(loadResult.value(), addTorrentParams);
                 Utils::Fs::removeFile(torrentPath);
 
                 return true;
