@@ -1,6 +1,6 @@
 /*
  * Bittorrent Client using Qt and libtorrent.
- * Copyright (C) 2022  Vladimir Golovnev <glassez@yandex.ru>
+ * Copyright (C) 2022-2024  Vladimir Golovnev <glassez@yandex.ru>
  * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -62,6 +62,13 @@ class TorrentCreatorDialog;
 class TransferListFiltersWidget;
 class TransferListWidget;
 
+#ifdef Q_OS_MACOS
+namespace MacUtils
+{
+    class Badger;
+}
+#endif
+
 namespace Net
 {
     struct DownloadResult;
@@ -72,13 +79,13 @@ namespace Ui
     class MainWindow;
 }
 
-class MainWindow final : public QMainWindow, public GUIApplicationComponent
+class MainWindow final : public GUIApplicationComponent<QMainWindow>
 {
     Q_OBJECT
     Q_DISABLE_COPY_MOVE(MainWindow)
 
 public:
-    explicit MainWindow(IGUIApplication *app, WindowState initialState = WindowState::Normal);
+    explicit MainWindow(IGUIApplication *app, WindowState initialState = WindowState::Normal, const QString &titleSuffix = {});
     ~MainWindow() override;
 
     QWidget *currentTabWidget() const;
@@ -91,12 +98,12 @@ public:
     Log::MsgTypes executionLogMsgTypes() const;
     void setExecutionLogMsgTypes(Log::MsgTypes value);
 
-    // Notifications properties
-
     // Misc properties
     bool isDownloadTrackerFavicon() const;
     void setDownloadTrackerFavicon(bool value);
 
+    void setTitleSuffix(const QString &suffix);
+
     void activate();
     void cleanup();
 
@@ -119,17 +126,13 @@ private slots:
     void displaySearchTab();
     void displayRSSTab();
     void displayExecutionLogTab();
-    void focusSearchFilter();
-    void reloadSessionStats();
-    void reloadTorrentStats(const QVector<BitTorrent::Torrent *> &torrents);
+    void toggleFocusBetweenLineEdits();
+    void loadSessionStats();
+    void reloadTorrentStats(const QList<BitTorrent::Torrent *> &torrents);
     void loadPreferences();
-    void askRecursiveTorrentDownloadConfirmation(const BitTorrent::Torrent *torrent);
     void optionsSaved();
     void toggleAlternativeSpeeds();
 
-#ifdef Q_OS_WIN
-    void pythonDownloadFinished(const Net::DownloadResult &result);
-#endif
     void addToolbarContextMenu();
     void manageCookies();
 
@@ -164,8 +167,8 @@ private slots:
     void on_actionDownloadFromURL_triggered();
     void on_actionExit_triggered();
     void on_actionLock_triggered();
-    // Check for unpaused downloading or seeding torrents and prevent system suspend/sleep according to preferences
-    void updatePowerManagementState();
+    // Check for non-stopped downloading or seeding torrents and prevent system suspend/sleep according to preferences
+    void updatePowerManagementState() const;
 
     void toolbarMenuRequested();
     void toolbarIconsOnly();
@@ -178,15 +181,13 @@ private slots:
 #else
     void toggleVisibility();
 #endif
-
-private:
-    QMenu *createDesktopIntegrationMenu();
 #ifdef Q_OS_WIN
-    void installPython();
+    void pythonDownloadFinished(const Net::DownloadResult &result);
 #endif
 
-    void dropEvent(QDropEvent *event) override;
-    void dragEnterEvent(QDragEnterEvent *event) override;
+private:
+    void populateDesktopIntegrationMenu();
+
     void closeEvent(QCloseEvent *) override;
     void showEvent(QShowEvent *) override;
     void keyPressEvent(QKeyEvent *event) override;
@@ -197,13 +198,24 @@ private:
     void showStatusBar(bool show);
     void showFiltersSidebar(bool show);
     void applyTransferListFilter();
+    void refreshWindowTitle();
+    void refreshTrayIconTooltip();
+
+#ifdef Q_OS_WIN
+    void installPython();
+    bool verifyPythonInstaller(const Path &installerPath) const;
+#endif
 
     Ui::MainWindow *m_ui = nullptr;
 
-    QFileSystemWatcher *m_executableWatcher = nullptr;
-    // GUI related
+    QString m_windowTitle;
+    QString m_downloadRate;
+    QString m_uploadRate;
     bool m_posInitialized = false;
     bool m_neverShown = true;
+
+    QFileSystemWatcher *m_executableWatcher = nullptr;
+    // GUI related
     QPointer<QTabWidget> m_tabs;
     QPointer<StatusBar> m_statusBar;
     QPointer<OptionsDialog> m_options;
@@ -235,7 +247,6 @@ private:
     // Power Management
     PowerManagement *m_pwr = nullptr;
     QTimer *m_preventTimer = nullptr;
-    bool m_hasPython = false;
     QMenu *m_toolbarMenu = nullptr;
 
     SettingValue<bool> m_storeExecutionLogEnabled;
@@ -248,4 +259,7 @@ private:
 
     QTimer *m_programUpdateTimer = nullptr;
 #endif
+#ifdef Q_OS_MACOS
+    std::unique_ptr<MacUtils::Badger> m_badger;
+#endif
 };
