@@ -48,16 +48,17 @@
 
 #define SETTINGS_KEY(name) u"PreviewSelectDialog/" name
 
+enum Roles
+{
+    SortRole = Qt::UserRole
+};
+
 PreviewSelectDialog::PreviewSelectDialog(QWidget *parent, const BitTorrent::Torrent *torrent)
     : QDialog(parent)
-    , m_ui(new Ui::PreviewSelectDialog)
-    , m_torrent(torrent)
-    , m_storeDialogSize(SETTINGS_KEY(u"Size"_s))
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
-    , m_storeTreeHeaderState(u"GUI/Qt6/" SETTINGS_KEY(u"HeaderState"_s))
-#else
-    , m_storeTreeHeaderState(SETTINGS_KEY(u"HeaderState"_s))
-#endif
+    , m_ui {new Ui::PreviewSelectDialog}
+    , m_torrent {torrent}
+    , m_storeDialogSize {SETTINGS_KEY(u"Size"_s)}
+    , m_storeTreeHeaderState {u"GUI/Qt6/" SETTINGS_KEY(u"HeaderState"_s)}
 {
     m_ui->setupUi(this);
 
@@ -79,13 +80,12 @@ PreviewSelectDialog::PreviewSelectDialog(QWidget *parent, const BitTorrent::Torr
     m_ui->previewList->setAlternatingRowColors(pref->useAlternatingRowColors());
     m_ui->previewList->setUniformRowHeights(true);
     m_ui->previewList->setModel(previewListModel);
-    m_ui->previewList->hideColumn(FILE_INDEX);
 
     auto *listDelegate = new PreviewListDelegate(this);
     m_ui->previewList->setItemDelegate(listDelegate);
 
     // Fill list in
-    const QVector<qreal> fp = torrent->filesProgress();
+    const QList<qreal> fp = torrent->filesProgress();
     for (int i = 0; i < torrent->filesCount(); ++i)
     {
         const Path filePath = torrent->filePath(i);
@@ -93,13 +93,19 @@ PreviewSelectDialog::PreviewSelectDialog(QWidget *parent, const BitTorrent::Torr
         {
             int row = previewListModel->rowCount();
             previewListModel->insertRow(row);
-            previewListModel->setData(previewListModel->index(row, NAME), filePath.filename());
-            previewListModel->setData(previewListModel->index(row, SIZE), Utils::Misc::friendlyUnit(torrent->fileSize(i)));
-            previewListModel->setData(previewListModel->index(row, PROGRESS), fp[i]);
-            previewListModel->setData(previewListModel->index(row, FILE_INDEX), i);
+            previewListModel->setData(previewListModel->index(row, NAME), filePath.filename(), Qt::DisplayRole);
+            previewListModel->setData(previewListModel->index(row, NAME), filePath.filename(), SortRole);
+            // Sorting file size by bytes, while displaying by human readable format
+            previewListModel->setData(previewListModel->index(row, SIZE), Utils::Misc::friendlyUnit(torrent->fileSize(i)), Qt::DisplayRole);
+            previewListModel->setData(previewListModel->index(row, SIZE), torrent->fileSize(i), SortRole);
+            previewListModel->setData(previewListModel->index(row, PROGRESS), fp[i], Qt::DisplayRole);
+            previewListModel->setData(previewListModel->index(row, PROGRESS), fp[i], SortRole);
+            previewListModel->setData(previewListModel->index(row, FILE_INDEX), i, Qt::DisplayRole);
+            previewListModel->setData(previewListModel->index(row, FILE_INDEX), i, SortRole);
         }
     }
 
+    previewListModel->setSortRole(SortRole);
     previewListModel->sort(NAME);
     m_ui->previewList->header()->setContextMenuPolicy(Qt::CustomContextMenu);
     m_ui->previewList->header()->setFirstSectionMovable(true);
@@ -110,6 +116,7 @@ PreviewSelectDialog::PreviewSelectDialog(QWidget *parent, const BitTorrent::Torr
 
     // Restore dialog state
     loadWindowState();
+    m_ui->previewList->hideColumn(FILE_INDEX);
 }
 
 PreviewSelectDialog::~PreviewSelectDialog()
