@@ -41,7 +41,7 @@ class PieceAvailabilityBar final : public PiecesBar
 public:
     PieceAvailabilityBar(QWidget *parent);
 
-    void setAvailability(const QVector<int> &avail);
+    void setAvailability(const QList<int> &avail);
 
     // PiecesBar interface
     void clear() override;
@@ -52,8 +52,8 @@ private:
 
     // last used int vector, uses to better resize redraw
     // TODO: make a diff pieces to new pieces and update only changed pixels, speedup when update > 20x faster
-    QVector<int> m_pieces;
+    QList<int> m_pieces;
 
     // scale int vector to float vector
-    QVector<float> intToFloatVector(const QVector<int> &vecin, int reqSize);
+    QList<float> intToFloatVector(const QList<int> &vecin, int reqSize);
 };
