@@ -1,5 +1,6 @@
 /*
  * Bittorrent Client using Qt and libtorrent.
+ * Copyright (C) 2024  Vladimir Golovnev <glassez@yandex.ru>
  * Copyright (C) 2016  Eugene Shalygin
  * Copyright (C) 2006  Christophe Dumez
  *
@@ -114,10 +115,10 @@ namespace
 }
 
 PiecesBar::PiecesBar(QWidget *parent)
-    : QWidget {parent}
+    : QWidget(parent)
 {
-    updatePieceColors();
     setMouseTracking(true);
+    updateColorsImpl();
 }
 
 void PiecesBar::setTorrent(const BitTorrent::Torrent *torrent)
@@ -135,20 +136,23 @@ void PiecesBar::clear()
 
 bool PiecesBar::event(QEvent *e)
 {
-    if (e->type() == QEvent::ToolTip)
+    const QEvent::Type eventType = e->type();
+    if (eventType == QEvent::ToolTip)
     {
         showToolTip(static_cast<QHelpEvent *>(e));
         return true;
     }
 
+    if (eventType == QEvent::PaletteChange)
+    {
+        updateColors();
+        redraw();
+    }
+
     return base::event(e);
 }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 void PiecesBar::enterEvent(QEnterEvent *e)
-#else
-void PiecesBar::enterEvent(QEvent *e)
-#endif
 {
     m_hovered = true;
     base::enterEvent(e);
@@ -158,7 +162,7 @@ void PiecesBar::leaveEvent(QEvent *e)
 {
     m_hovered = false;
     m_highlightedRegion = {};
-    requestImageUpdate();
+    redraw();
     base::leaveEvent(e);
 }
 
@@ -182,16 +186,17 @@ void PiecesBar::paintEvent(QPaintEvent *)
     else
     {
         if (m_image.width() != imageRect.width())
-            updateImage(m_image);
+        {
+            if (const QImage image = renderImage(); !image.isNull())
+                m_image = image;
+        }
         painter.drawImage(imageRect, m_image);
     }
 
     if (!m_highlightedRegion.isNull())
     {
-        QColor highlightColor {this->palette().color(QPalette::Active, QPalette::Highlight)};
-        highlightColor.setAlphaF(0.35f);
         QRect targetHighlightRect {m_highlightedRegion.adjusted(borderWidth, borderWidth, borderWidth, height() - 2 * borderWidth)};
-        painter.fillRect(targetHighlightRect, highlightColor);
+        painter.fillRect(targetHighlightRect, highlightedPieceColor());
     }
 
     QPainterPath border;
@@ -200,33 +205,43 @@ void PiecesBar::paintEvent(QPaintEvent *)
     painter.drawPath(border);
 }
 
-void PiecesBar::requestImageUpdate()
+void PiecesBar::redraw()
 {
-    if (updateImage(m_image))
+    if (const QImage image = renderImage(); !image.isNull())
+    {
+        m_image = image;
         update();
+    }
 }
 
 QColor PiecesBar::backgroundColor() const
 {
-    return palette().color(QPalette::Base);
+    return palette().color(QPalette::Active, QPalette::Base);
 }
 
 QColor PiecesBar::borderColor() const
 {
-    return palette().color(QPalette::Dark);
+    return palette().color(QPalette::Active, QPalette::Dark);
 }
 
 QColor PiecesBar::pieceColor() const
 {
-    return palette().color(QPalette::Highlight);
+    return palette().color(QPalette::Active, QPalette::Highlight);
+}
+
+QColor PiecesBar::highlightedPieceColor() const
+{
+    QColor col = palette().color(QPalette::Highlight).darker();
+    col.setAlphaF(0.35);
+    return col;
 }
 
 QColor PiecesBar::colorBoxBorderColor() const
 {
-    return palette().color(QPalette::ToolTipText);
+    return palette().color(QPalette::Active, QPalette::ToolTipText);
 }
 
-const QVector<QRgb> &PiecesBar::pieceColors() const
+const QList<QRgb> &PiecesBar::pieceColors() const
 {
     return m_pieceColors;
 }
@@ -265,7 +280,7 @@ void PiecesBar::showToolTip(const QHelpEvent *e)
         {
             const PieceIndexToImagePos transform {torrentInfo, m_image};
             const int pieceIndex = transform.pieceIndex(imagePos);
-            const QVector<int> fileIndexes = torrentInfo.fileIndicesForPiece(pieceIndex);
+            const QList<int> fileIndexes = torrentInfo.fileIndicesForPiece(pieceIndex);
 
             QString tooltipTitle;
             if (fileIndexes.count() > 1)
@@ -309,7 +324,7 @@ void PiecesBar::highlightFile(int imagePos)
     PieceIndexToImagePos transform {torrentInfo, m_image};
 
     int pieceIndex = transform.pieceIndex(imagePos);
-    QVector<int> fileIndices {torrentInfo.fileIndicesForPiece(pieceIndex)};
+    QList<int> fileIndices {torrentInfo.fileIndicesForPiece(pieceIndex)};
     if (fileIndices.count() == 1)
     {
         BitTorrent::TorrentInfo::PieceRange filePieces = torrentInfo.filePieces(fileIndices.first());
@@ -329,12 +344,17 @@ void PiecesBar::highlightFile(int imagePos)
     }
 }
 
-void PiecesBar::updatePieceColors()
+void PiecesBar::updateColors()
 {
-    m_pieceColors = QVector<QRgb>(256);
+    updateColorsImpl();
+}
+
+void PiecesBar::updateColorsImpl()
+{
+    m_pieceColors = QList<QRgb>(256);
     for (int i = 0; i < 256; ++i)
     {
-        float ratio = (i / 255.0);
+        const float ratio = (i / 255.0);
         m_pieceColors[i] = mixTwoColors(backgroundColor().rgb(), pieceColor().rgb(), ratio);
     }
 }
