@@ -37,9 +37,6 @@
 class QListWidgetItem;
 class QTreeWidgetItem;
 
-class ArticleListWidget;
-class FeedListWidget;
-
 namespace RSS
 {
     class Article;
@@ -94,6 +91,4 @@ private:
     void renderArticle(const RSS::Article *article) const;
 
     Ui::RSSWidget *m_ui = nullptr;
-    ArticleListWidget *m_articleListWidget = nullptr;
-    FeedListWidget *m_feedListWidget = nullptr;
 };
