@@ -28,76 +28,76 @@
 
 "use strict";
 
-if (window.qBittorrent === undefined)
-    window.qBittorrent = {};
-
-window.qBittorrent.ProgressBar = (function() {
-    const exports = function() {
+window.qBittorrent ??= {};
+window.qBittorrent.ProgressBar ??= (() => {
+    const exports = () => {
         return {
             ProgressBar: ProgressBar
         };
     };
 
-    let ProgressBars = 0;
+    let progressBars = 0;
     const ProgressBar = new Class({
-        initialize: function(value, parameters) {
+        initialize: (value, parameters) => {
             const vals = {
-                "id": "progressbar_" + (ProgressBars++),
-                "value": [value, 0].pick(),
-                "width": 0,
-                "height": 0,
-                "darkbg": "var(--color-background-blue)",
-                "darkfg": "var(--color-text-white)",
-                "lightbg": "var(--color-background-default)",
-                "lightfg": "var(--color-text-default)"
+                id: `progressbar_${progressBars++}`,
+                value: [value, 0].pick(),
+                width: 0,
+                height: 0,
+                darkbg: "var(--color-background-blue)",
+                darkfg: "var(--color-text-white)",
+                lightbg: "var(--color-background-default)",
+                lightfg: "var(--color-text-default)"
             };
             if (parameters && (typeOf(parameters) === "object"))
                 Object.append(vals, parameters);
             if (vals.height < 12)
                 vals.height = 12;
-            const obj = new Element("div", {
-                "id": vals.id,
-                "class": "progressbar_wrapper",
-                "styles": {
-                    "border": "1px solid var(--color-border-default)",
-                    "width": vals.width,
-                    "height": vals.height,
-                    "position": "relative",
-                    "margin": "0 auto"
-                }
-            });
+
+            const obj = document.createElement("div");
+            obj.id = vals.id;
+            obj.className = "progressbar_wrapper";
+            obj.style.border = "1px solid var(--color-border-default)";
+            obj.style.boxSizing = "content-box";
+            obj.style.width = `${vals.width}px`;
+            obj.style.height = `${vals.height}px`;
+            obj.style.position = "relative";
+            obj.style.margin = "0 auto";
             obj.vals = vals;
             obj.vals.value = [value, 0].pick();
-            obj.vals.dark = new Element("div", {
-                "id": vals.id + "_dark",
-                "class": "progressbar_dark",
-                "styles": {
-                    "width": vals.width,
-                    "height": vals.height,
-                    "background": vals.darkbg,
-                    "color": vals.darkfg,
-                    "position": "absolute",
-                    "text-align": "center",
-                    "left": 0,
-                    "top": 0,
-                    "line-height": vals.height
-                }
-            });
-            obj.vals.light = new Element("div", {
-                "id": vals.id + "_light",
-                "class": "progressbar_light",
-                "styles": {
-                    "width": vals.width,
-                    "height": vals.height,
-                    "background": vals.lightbg,
-                    "color": vals.lightfg,
-                    "position": "absolute",
-                    "text-align": "center",
-                    "left": 0,
-                    "top": 0,
-                    "line-height": vals.height
-                }
-            });
+
+            const dark = document.createElement("div");
+            dark.id = `${vals.id}_dark`;
+            dark.className = "progressbar_dark";
+            dark.style.width = `${vals.width}px`;
+            dark.style.height = `${vals.height}px`;
+            dark.style.background = vals.darkbg;
+            dark.style.boxSizing = "content-box";
+            dark.style.color = vals.darkfg;
+            dark.style.position = "absolute";
+            dark.style.textAlign = "center";
+            dark.style.left = "0";
+            dark.style.top = "0";
+            dark.style.lineHeight = `${vals.height}px`;
+
+            obj.vals.dark = dark;
+
+            const light = document.createElement("div");
+            light.id = `${vals.id}_light`;
+            light.className = "progressbar_light";
+            light.style.width = `${vals.width}px`;
+            light.style.height = `${vals.height}px`;
+            light.style.background = vals.lightbg;
+            light.style.boxSizing = "content-box";
+            light.style.color = vals.lightfg;
+            light.style.position = "absolute";
+            light.style.textAlign = "center";
+            light.style.left = "0";
+            light.style.top = "0";
+            light.style.lineHeight = `${vals.height}px`;
+
+            obj.vals.light = light;
+
             obj.appendChild(obj.vals.dark);
             obj.appendChild(obj.vals.light);
             obj.getValue = ProgressBar_getValue;
@@ -106,7 +106,7 @@ window.qBittorrent.ProgressBar = (function() {
             if (vals.width)
                 obj.setValue(vals.value);
             else
-                setTimeout('ProgressBar_checkForParent("' + obj.id + '")', 1);
+                setTimeout(ProgressBar_checkForParent, 0, obj.id);
             return obj;
         }
     });
@@ -126,36 +126,35 @@ window.qBittorrent.ProgressBar = (function() {
         this.vals.dark.textContent = displayedValue;
         this.vals.light.textContent = displayedValue;
 
-        const r = parseInt((this.vals.width * (value / 100)), 10);
-        this.vals.dark.setStyle("clip", `rect(0, ${r}px, ${this.vals.height}px, 0)`);
-        this.vals.light.setStyle("clip", `rect(0, ${this.vals.width}px, ${this.vals.height}px, ${r}px)`);
+        const r = Number(this.vals.width * (value / 100));
+        this.vals.dark.style.clipPath = `inset(0 calc(100% - ${r}px) 0 0)`;
+        this.vals.light.style.clipPath = `inset(0 0 0 ${r}px)`;
     }
 
     function ProgressBar_setWidth(value) {
         if (this.vals.width !== value) {
             this.vals.width = value;
-            this.setStyle("width", value);
-            this.vals.dark.setStyle("width", value);
-            this.vals.light.setStyle("width", value);
+            this.style.width = `${value}px`;
+            this.vals.dark.style.width = `${value}px`;
+            this.vals.light.style.width = `${value}px`;
             this.setValue(this.vals.value);
         }
     }
 
-    function ProgressBar_checkForParent(id) {
+    const ProgressBar_checkForParent = (id) => {
         const obj = $(id);
         if (!obj)
             return;
         if (!obj.parentNode)
-            return setTimeout('ProgressBar_checkForParent("' + id + '")', 1);
-        obj.setStyle("width", "100%");
+            return setTimeout(ProgressBar_checkForParent, 100, id);
+        obj.style.width = "100%";
         const w = obj.offsetWidth;
-        obj.vals.dark.setStyle("width", w);
-        obj.vals.light.setStyle("width", w);
+        obj.vals.dark.style.width = `${w}px`;
+        obj.vals.light.style.width = `${w}px`;
         obj.vals.width = w;
         obj.setValue(obj.vals.value);
-    }
+    };
 
     return exports();
 })();
-
 Object.freeze(window.qBittorrent.ProgressBar);
