@@ -28,56 +28,56 @@
 
 "use strict";
 
-if (window.qBittorrent === undefined)
-    window.qBittorrent = {};
-
-window.qBittorrent.PropGeneral = (function() {
-    const exports = function() {
+window.qBittorrent ??= {};
+window.qBittorrent.PropGeneral ??= (() => {
+    const exports = () => {
         return {
-            updateData: updateData
+            updateData: updateData,
+            clear: clear
         };
     };
 
     const piecesBar = new window.qBittorrent.PiecesBar.PiecesBar([], {
-        height: 16
+        height: 18
     });
     $("progress").appendChild(piecesBar);
 
-    const clearData = function() {
-        $("time_elapsed").set("html", "");
-        $("eta").set("html", "");
-        $("nb_connections").set("html", "");
-        $("total_downloaded").set("html", "");
-        $("total_uploaded").set("html", "");
-        $("dl_speed").set("html", "");
-        $("up_speed").set("html", "");
-        $("dl_limit").set("html", "");
-        $("up_limit").set("html", "");
-        $("total_wasted").set("html", "");
-        $("seeds").set("html", "");
-        $("peers").set("html", "");
-        $("share_ratio").set("html", "");
-        $("popularity").set("html", "");
-        $("reannounce").set("html", "");
-        $("last_seen").set("html", "");
-        $("total_size").set("html", "");
-        $("pieces").set("html", "");
-        $("created_by").set("html", "");
-        $("addition_date").set("html", "");
-        $("completion_date").set("html", "");
-        $("creation_date").set("html", "");
-        $("torrent_hash_v1").set("html", "");
-        $("torrent_hash_v2").set("html", "");
-        $("save_path").set("html", "");
-        $("comment").set("html", "");
-        $("private").set("html", "");
+    const clearData = () => {
+        document.getElementById("progressPercentage").textContent = "";
+        $("time_elapsed").textContent = "";
+        $("eta").textContent = "";
+        $("nb_connections").textContent = "";
+        $("total_downloaded").textContent = "";
+        $("total_uploaded").textContent = "";
+        $("dl_speed").textContent = "";
+        $("up_speed").textContent = "";
+        $("dl_limit").textContent = "";
+        $("up_limit").textContent = "";
+        $("total_wasted").textContent = "";
+        $("seeds").textContent = "";
+        $("peers").textContent = "";
+        $("share_ratio").textContent = "";
+        $("popularity").textContent = "";
+        $("reannounce").textContent = "";
+        $("last_seen").textContent = "";
+        $("total_size").textContent = "";
+        $("pieces").textContent = "";
+        $("created_by").textContent = "";
+        $("addition_date").textContent = "";
+        $("completion_date").textContent = "";
+        $("creation_date").textContent = "";
+        $("torrent_hash_v1").textContent = "";
+        $("torrent_hash_v2").textContent = "";
+        $("save_path").textContent = "";
+        $("comment").textContent = "";
+        $("private").textContent = "";
         piecesBar.clear();
     };
 
-    let loadTorrentDataTimer;
-    const loadTorrentData = function() {
-        if ($("prop_general").hasClass("invisible")
-            || $("propertiesPanel_collapseToggle").hasClass("panel-expand")) {
+    let loadTorrentDataTimer = -1;
+    const loadTorrentData = () => {
+        if ($("propGeneral").classList.contains("invisible")
+            || $("propertiesPanel_collapseToggle").classList.contains("panel-expand")) {
             // Tab changed, don't do anything
             return;
         }
@@ -85,93 +85,102 @@ window.qBittorrent.PropGeneral = (function() {
         if (current_id === "") {
             clearData();
             clearTimeout(loadTorrentDataTimer);
-            loadTorrentDataTimer = loadTorrentData.delay(5000);
             return;
         }
-        const url = new URI("api/v2/torrents/properties?hash=" + current_id);
-        new Request.JSON({
-            url: url,
-            method: "get",
-            noCache: true,
-            onFailure: function() {
-                $("error_div").set("html", "QBT_TR(qBittorrent client is not reachable)QBT_TR[CONTEXT=HttpServer]");
-                clearTimeout(loadTorrentDataTimer);
-                loadTorrentDataTimer = loadTorrentData.delay(10000);
-            },
-            onSuccess: function(data) {
-                $("error_div").set("html", "");
+
+        const propertiesURL = new URL("api/v2/torrents/properties", window.location);
+        propertiesURL.search = new URLSearchParams({
+            hash: current_id
+        });
+        fetch(propertiesURL, {
+                method: "GET",
+                cache: "no-store"
+            })
+            .then(async (response) => {
+                if (!response.ok) {
+                    $("error_div").textContent = "QBT_TR(qBittorrent client is not reachable)QBT_TR[CONTEXT=HttpServer]";
+                    clearTimeout(loadTorrentDataTimer);
+                    loadTorrentDataTimer = loadTorrentData.delay(10000);
+                    return;
+                }
+
+                $("error_div").textContent = "";
+
+                const data = await response.json();
                 if (data) {
                     // Update Torrent data
 
+                    document.getElementById("progressPercentage").textContent = window.qBittorrent.Misc.friendlyPercentage(data.progress);
+
                     const timeElapsed = (data.seeding_time > 0)
                         ? "QBT_TR(%1 (seeded for %2))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", window.qBittorrent.Misc.friendlyDuration(data.time_elapsed))
                         .replace("%2", window.qBittorrent.Misc.friendlyDuration(data.seeding_time))
                         : window.qBittorrent.Misc.friendlyDuration(data.time_elapsed);
-                    $("time_elapsed").set("html", timeElapsed);
+                    $("time_elapsed").textContent = timeElapsed;
 
-                    $("eta").set("html", window.qBittorrent.Misc.friendlyDuration(data.eta, window.qBittorrent.Misc.MAX_ETA));
+                    $("eta").textContent = window.qBittorrent.Misc.friendlyDuration(data.eta, window.qBittorrent.Misc.MAX_ETA);
 
                     const nbConnections = "QBT_TR(%1 (%2 max))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", data.nb_connections)
                         .replace("%2", ((data.nb_connections_limit < 0) ? "∞" : data.nb_connections_limit));
-                    $("nb_connections").set("html", nbConnections);
+                    $("nb_connections").textContent = nbConnections;
 
                     const totalDownloaded = "QBT_TR(%1 (%2 this session))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", window.qBittorrent.Misc.friendlyUnit(data.total_downloaded))
                         .replace("%2", window.qBittorrent.Misc.friendlyUnit(data.total_downloaded_session));
-                    $("total_downloaded").set("html", totalDownloaded);
+                    $("total_downloaded").textContent = totalDownloaded;
 
                     const totalUploaded = "QBT_TR(%1 (%2 this session))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", window.qBittorrent.Misc.friendlyUnit(data.total_uploaded))
                         .replace("%2", window.qBittorrent.Misc.friendlyUnit(data.total_uploaded_session));
-                    $("total_uploaded").set("html", totalUploaded);
+                    $("total_uploaded").textContent = totalUploaded;
 
                     const dlSpeed = "QBT_TR(%1 (%2 avg.))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", window.qBittorrent.Misc.friendlyUnit(data.dl_speed, true))
                         .replace("%2", window.qBittorrent.Misc.friendlyUnit(data.dl_speed_avg, true));
-                    $("dl_speed").set("html", dlSpeed);
+                    $("dl_speed").textContent = dlSpeed;
 
                     const upSpeed = "QBT_TR(%1 (%2 avg.))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", window.qBittorrent.Misc.friendlyUnit(data.up_speed, true))
                         .replace("%2", window.qBittorrent.Misc.friendlyUnit(data.up_speed_avg, true));
-                    $("up_speed").set("html", upSpeed);
+                    $("up_speed").textContent = upSpeed;
 
                     const dlLimit = (data.dl_limit === -1)
                         ? "∞"
                         : window.qBittorrent.Misc.friendlyUnit(data.dl_limit, true);
-                    $("dl_limit").set("html", dlLimit);
+                    $("dl_limit").textContent = dlLimit;
 
                     const upLimit = (data.up_limit === -1)
                         ? "∞"
                         : window.qBittorrent.Misc.friendlyUnit(data.up_limit, true);
-                    $("up_limit").set("html", upLimit);
+                    $("up_limit").textContent = upLimit;
 
-                    $("total_wasted").set("html", window.qBittorrent.Misc.friendlyUnit(data.total_wasted));
+                    $("total_wasted").textContent = window.qBittorrent.Misc.friendlyUnit(data.total_wasted);
 
                     const seeds = "QBT_TR(%1 (%2 total))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", data.seeds)
                         .replace("%2", data.seeds_total);
-                    $("seeds").set("html", seeds);
+                    $("seeds").textContent = seeds;
 
                     const peers = "QBT_TR(%1 (%2 total))QBT_TR[CONTEXT=PropertiesWidget]"
                         .replace("%1", data.peers)
                         .replace("%2", data.peers_total);
-                    $("peers").set("html", peers);
+                    $("peers").textContent = peers;
 
-                    $("share_ratio").set("html", data.share_ratio.toFixed(2));
+                    $("share_ratio").textContent = data.share_ratio.toFixed(2);
 
-                    $("popularity").set("html", data.popularity.toFixed(2));
+                    $("popularity").textContent = data.popularity.toFixed(2);
 
-                    $("reannounce").set("html", window.qBittorrent.Misc.friendlyDuration(data.reannounce));
+                    $("reannounce").textContent = window.qBittorrent.Misc.friendlyDuration(data.reannounce);
 
                     const lastSeen = (data.last_seen >= 0)
                         ? new Date(data.last_seen * 1000).toLocaleString()
                         : "QBT_TR(Never)QBT_TR[CONTEXT=PropertiesWidget]";
-                    $("last_seen").set("html", lastSeen);
+                    $("last_seen").textContent = lastSeen;
 
                     const totalSize = (data.total_size >= 0) ? window.qBittorrent.Misc.friendlyUnit(data.total_size) : "";
-                    $("total_size").set("html", totalSize);
+                    $("total_size").textContent = totalSize;
 
                     const pieces = (data.pieces_num >= 0)
                         ? "QBT_TR(%1 x %2 (have %3))QBT_TR[CONTEXT=PropertiesWidget]"
@@ -179,69 +188,71 @@ window.qBittorrent.PropGeneral = (function() {
                         .replace("%2", window.qBittorrent.Misc.friendlyUnit(data.piece_size))
                         .replace("%3", data.pieces_have)
                         : "";
-                    $("pieces").set("html", pieces);
+                    $("pieces").textContent = pieces;
 
-                    $("created_by").set("text", data.created_by);
+                    $("created_by").textContent = data.created_by;
 
                     const additionDate = (data.addition_date >= 0)
                         ? new Date(data.addition_date * 1000).toLocaleString()
                         : "QBT_TR(Unknown)QBT_TR[CONTEXT=HttpServer]";
-                    $("addition_date").set("html", additionDate);
+                    $("addition_date").textContent = additionDate;
 
                     const completionDate = (data.completion_date >= 0)
                         ? new Date(data.completion_date * 1000).toLocaleString()
                         : "";
-                    $("completion_date").set("html", completionDate);
+                    $("completion_date").textContent = completionDate;
 
                     const creationDate = (data.creation_date >= 0)
                         ? new Date(data.creation_date * 1000).toLocaleString()
                         : "";
-                    $("creation_date").set("html", creationDate);
+                    $("creation_date").textContent = creationDate;
 
                     const torrentHashV1 = (data.infohash_v1 !== "")
                         ? data.infohash_v1
                         : "QBT_TR(N/A)QBT_TR[CONTEXT=PropertiesWidget]";
-                    $("torrent_hash_v1").set("html", torrentHashV1);
+                    $("torrent_hash_v1").textContent = torrentHashV1;
 
                     const torrentHashV2 = (data.infohash_v2 !== "")
                         ? data.infohash_v2
                         : "QBT_TR(N/A)QBT_TR[CONTEXT=PropertiesWidget]";
-                    $("torrent_hash_v2").set("html", torrentHashV2);
+                    $("torrent_hash_v2").textContent = torrentHashV2;
 
-                    $("save_path").set("html", data.save_path);
+                    $("save_path").textContent = data.save_path;
 
-                    $("comment").set("html", window.qBittorrent.Misc.parseHtmlLinks(window.qBittorrent.Misc.escapeHtml(data.comment)));
+                    $("comment").innerHTML = window.qBittorrent.Misc.parseHtmlLinks(window.qBittorrent.Misc.escapeHtml(data.comment));
 
-                    if (data.has_metadata) {
-                        $("private").set("text", (data.private
+                    $("private").textContent = (data.has_metadata
+                        ? (data.private
                             ? "QBT_TR(Yes)QBT_TR[CONTEXT=PropertiesWidget]"
-                            : "QBT_TR(No)QBT_TR[CONTEXT=PropertiesWidget]"));
-                    }
-                    else {
-                        $("private").set("text", "QBT_TR(N/A)QBT_TR[CONTEXT=PropertiesWidget]");
-                    }
+                            : "QBT_TR(No)QBT_TR[CONTEXT=PropertiesWidget]")
+                        : "QBT_TR(N/A)QBT_TR[CONTEXT=PropertiesWidget]");
                 }
                 else {
                     clearData();
                 }
                 clearTimeout(loadTorrentDataTimer);
                 loadTorrentDataTimer = loadTorrentData.delay(5000);
-            }
-        }).send();
+            });
 
-        const piecesUrl = new URI("api/v2/torrents/pieceStates?hash=" + current_id);
-        new Request.JSON({
-            url: piecesUrl,
-            method: "get",
-            noCache: true,
-            onFailure: function() {
-                $("error_div").set("html", "QBT_TR(qBittorrent client is not reachable)QBT_TR[CONTEXT=HttpServer]");
-                clearTimeout(loadTorrentDataTimer);
-                loadTorrentDataTimer = loadTorrentData.delay(10000);
-            },
-            onSuccess: function(data) {
-                $("error_div").set("html", "");
+        const pieceStatesURL = new URL("api/v2/torrents/pieceStates", window.location);
+        pieceStatesURL.search = new URLSearchParams({
+            hash: current_id
+        });
+        fetch(pieceStatesURL, {
+                method: "GET",
+                cache: "no-store"
+            })
+            .then(async (response) => {
+                if (!response.ok) {
+                    $("error_div").textContent = "QBT_TR(qBittorrent client is not reachable)QBT_TR[CONTEXT=HttpServer]";
+                    clearTimeout(loadTorrentDataTimer);
+                    loadTorrentDataTimer = loadTorrentData.delay(10000);
+                    return;
+                }
 
+                $("error_div").textContent = "";
+
+                const data = await response.json();
                 if (data)
                     piecesBar.setPieces(data);
                 else
@@ -249,16 +260,19 @@ window.qBittorrent.PropGeneral = (function() {
 
                 clearTimeout(loadTorrentDataTimer);
                 loadTorrentDataTimer = loadTorrentData.delay(5000);
-            }
-        }).send();
+            });
     };
 
-    const updateData = function() {
+    const updateData = () => {
         clearTimeout(loadTorrentDataTimer);
+        loadTorrentDataTimer = -1;
         loadTorrentData();
     };
 
+    const clear = () => {
+        clearData();
+    };
+
     return exports();
 })();
-
 Object.freeze(window.qBittorrent.PropGeneral);
