@@ -26,27 +26,25 @@
  * exception statement from your version.
  */
 
-'use strict';
+"use strict";
 
-if (window.qBittorrent === undefined) {
-    window.qBittorrent = {};
-}
-
-window.qBittorrent.PropPeers = (function() {
-    const exports = function() {
+window.qBittorrent ??= {};
+window.qBittorrent.PropPeers ??= (() => {
+    const exports = () => {
         return {
-            updateData: updateData
-        }
+            updateData: updateData,
+            clear: clear
+        };
     };
 
     const torrentPeersTable = new window.qBittorrent.DynamicTable.TorrentPeersTable();
-    let loadTorrentPeersTimer;
+    let loadTorrentPeersTimer = -1;
     let syncTorrentPeersLastResponseId = 0;
     let show_flags = true;
 
-    const loadTorrentPeersData = function() {
-        if ($('prop_peers').hasClass('invisible')
-            || $('propertiesPanel_collapseToggle').hasClass('panel-expand')) {
+    const loadTorrentPeersData = () => {
+        if ($("propPeers").classList.contains("invisible")
+            || $("propertiesPanel_collapseToggle").classList.contains("panel-expand")) {
             syncTorrentPeersLastResponseId = 0;
             torrentPeersTable.clear();
             return;
@@ -56,131 +54,141 @@ window.qBittorrent.PropPeers = (function() {
             syncTorrentPeersLastResponseId = 0;
             torrentPeersTable.clear();
             clearTimeout(loadTorrentPeersTimer);
-            loadTorrentPeersTimer = loadTorrentPeersData.delay(getSyncMainDataInterval());
             return;
         }
-        const url = new URI('api/v2/sync/torrentPeers');
-        url.setData('rid', syncTorrentPeersLastResponseId);
-        url.setData('hash', current_hash);
-        new Request.JSON({
-            url: url,
-            noCache: true,
-            method: 'get',
-            onComplete: function() {
-                clearTimeout(loadTorrentPeersTimer);
-                loadTorrentPeersTimer = loadTorrentPeersData.delay(getSyncMainDataInterval());
-            },
-            onSuccess: function(response) {
-                $('error_div').set('html', '');
-                if (response) {
-                    const full_update = (response['full_update'] === true);
+        const url = new URL("api/v2/sync/torrentPeers", window.location);
+        url.search = new URLSearchParams({
+            hash: current_hash,
+            rid: syncTorrentPeersLastResponseId,
+        });
+        fetch(url, {
+                method: "GET",
+                cache: "no-store"
+            })
+            .then(async (response) => {
+                if (!response.ok)
+                    return;
+
+                const responseJSON = await response.json();
+
+                $("error_div").textContent = "";
+                if (responseJSON) {
+                    const full_update = (responseJSON["full_update"] === true);
                     if (full_update)
                         torrentPeersTable.clear();
-                    if (response['rid'])
-                        syncTorrentPeersLastResponseId = response['rid'];
-                    if (response['peers']) {
-                        for (const key in response['peers']) {
-                            response['peers'][key]['rowId'] = key;
+                    if (responseJSON["rid"])
+                        syncTorrentPeersLastResponseId = responseJSON["rid"];
+                    if (responseJSON["peers"]) {
+                        for (const key in responseJSON["peers"]) {
+                            if (!Object.hasOwn(responseJSON["peers"], key))
+                                continue;
 
-                            torrentPeersTable.updateRowData(response['peers'][key]);
+                            responseJSON["peers"][key]["rowId"] = key;
+                            torrentPeersTable.updateRowData(responseJSON["peers"][key]);
                         }
                     }
-                    if (response['peers_removed']) {
-                        response['peers_removed'].each(function(hash) {
+                    if (responseJSON["peers_removed"]) {
+                        responseJSON["peers_removed"].each((hash) => {
                             torrentPeersTable.removeRow(hash);
                         });
                     }
                     torrentPeersTable.updateTable(full_update);
-                    torrentPeersTable.altRow();
 
-                    if (response['show_flags']) {
-                        if (show_flags != response['show_flags']) {
-                            show_flags = response['show_flags'];
-                            torrentPeersTable.columns['country'].force_hide = !show_flags;
-                            torrentPeersTable.updateColumn('country');
+                    if (responseJSON["show_flags"]) {
+                        if (show_flags !== responseJSON["show_flags"]) {
+                            show_flags = responseJSON["show_flags"];
+                            torrentPeersTable.columns["country"].force_hide = !show_flags;
+                            torrentPeersTable.updateColumn("country");
                         }
                     }
                 }
                 else {
                     torrentPeersTable.clear();
                 }
-            }
-        }).send();
+
+            })
+            .finally(() => {
+                clearTimeout(loadTorrentPeersTimer);
+                loadTorrentPeersTimer = loadTorrentPeersData.delay(window.qBittorrent.Client.getSyncMainDataInterval());
+            });
     };
 
-    const updateData = function() {
+    const updateData = () => {
         clearTimeout(loadTorrentPeersTimer);
+        loadTorrentPeersTimer = -1;
         loadTorrentPeersData();
     };
 
+    const clear = () => {
+        torrentPeersTable.clear();
+    };
+
     const torrentPeersContextMenu = new window.qBittorrent.ContextMenu.ContextMenu({
-        targets: '#torrentPeersTableDiv',
-        menu: 'torrentPeersMenu',
+        targets: "#torrentPeersTableDiv",
+        menu: "torrentPeersMenu",
         actions: {
-            addPeer: function(element, ref) {
+            addPeer: (element, ref) => {
                 const hash = torrentsTable.getCurrentTorrentID();
                 if (!hash)
                     return;
 
                 new MochaUI.Window({
-                    id: 'addPeersPage',
+                    id: "addPeersPage",
+                    icon: "images/qbittorrent-tray.svg",
                     title: "QBT_TR(Add Peers)QBT_TR[CONTEXT=PeersAdditionDialog]",
-                    loadMethod: 'iframe',
-                    contentURL: 'addpeers.html?hash=' + hash,
+                    loadMethod: "iframe",
+                    contentURL: `addpeers.html?hash=${hash}`,
                     scrollbars: false,
                     resizable: false,
                     maximizable: false,
                     paddingVertical: 0,
                     paddingHorizontal: 0,
                     width: 350,
-                    height: 240
+                    height: 260
                 });
             },
-            banPeer: function(element, ref) {
+            banPeer: (element, ref) => {
                 const selectedPeers = torrentPeersTable.selectedRowsIds();
                 if (selectedPeers.length === 0)
                     return;
 
-                if (confirm('QBT_TR(Are you sure you want to permanently ban the selected peers?)QBT_TR[CONTEXT=PeerListWidget]')) {
-                    new Request({
-                        url: 'api/v2/transfer/banPeers',
-                        noCache: true,
-                        method: 'post',
-                        data: {
+                if (confirm("QBT_TR(Are you sure you want to permanently ban the selected peers?)QBT_TR[CONTEXT=PeerListWidget]")) {
+                    fetch("api/v2/transfer/banPeers", {
+                        method: "POST",
+                        body: new URLSearchParams({
                             hash: torrentsTable.getCurrentTorrentID(),
-                            peers: selectedPeers.join('|')
-                        }
-                    }).send();
+                            peers: selectedPeers.join("|")
+                        })
+                    });
                 }
             }
         },
         offsets: {
-            x: -15,
+            x: 0,
             y: 2
         },
         onShow: function() {
             const selectedPeers = torrentPeersTable.selectedRowsIds();
 
             if (selectedPeers.length >= 1) {
-                this.showItem('copyPeer');
-                this.showItem('banPeer');
+                this.showItem("copyPeer");
+                this.showItem("banPeer");
             }
             else {
-                this.hideItem('copyPeer');
-                this.hideItem('banPeer');
+                this.hideItem("copyPeer");
+                this.hideItem("banPeer");
             }
         }
     });
 
-    new ClipboardJS('#CopyPeerInfo', {
-        text: function(trigger) {
+    new ClipboardJS("#CopyPeerInfo", {
+        text: (trigger) => {
             return torrentPeersTable.selectedRowsIds().join("\n");
         }
     });
 
-    torrentPeersTable.setup('torrentPeersTableDiv', 'torrentPeersTableFixedHeaderDiv', torrentPeersContextMenu);
+    torrentPeersTable.setup("torrentPeersTableDiv", "torrentPeersTableFixedHeaderDiv", torrentPeersContextMenu);
 
     return exports();
 })();
-
 Object.freeze(window.qBittorrent.PropPeers);
